pub struct HoverContainer<'a, Message, Renderer: Renderer> { /* private fields */ }

Implementations

Sets the [Padding] of the iced::Container.

Sets the width of the iced::Container.

Sets the height of the iced::Container.

Sets the maximum width of the iced::Container.

Sets the maximum height of the iced::Container in pixels.

Sets the content alignment for the horizontal axis of the iced::Container.

Sets the content alignment for the vertical axis of the iced::Container.

Centers the contents in the horizontal axis of the iced::Container.

Centers the contents in the vertical axis of the iced::Container.

Sets the stylesheet of the iced::Container.